<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CutWithReference</name>
    <message>
        <location filename="../CutWithReferenceInit.js" line="+2"/>
        <source>&amp;Cut with Reference</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wytnij z o&amp;dniesieniem</translation>
    </message>
</context>
</TS>
